sequencetools.remove_subsequence_of_weight_at_index
===================================================

.. autofunction:: abjad.tools.sequencetools.remove_subsequence_of_weight_at_index.remove_subsequence_of_weight_at_index
